Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type User ¶
type User struct {
Id bson.ObjectId `bson:"_id"`
Name string `bson:"name"`
Email string `bson:"email"`
Password string `bson:"password"`
Role string `bson:"role"`
Created time.Time `bson:"created"`
Updated time.Time `bson:"updated"`
}
User provides the user instance for authentication job.
func (*User) FromProtoBuffer ¶
FromProtoBuffer gets user from protocol buffer and converts to the user structure.
func (*User) ToProtoBuffer ¶
ToProtoBuffer converts the user structure into a protocol buffer user structure.
Click to show internal directories.
Click to hide internal directories.